@@ -110,7 +110,7 @@ new LambdaToElasticSearchAndKibana(this, "sample",
 |domainName|`string`|Domain name for the Cognito and the Elasticsearch Service|
 |cognitoDomainName?|`string`|Optional Cognito Domain Name, if provided it will be used for Cognito Domain, and domainName will be used for the Elasticsearch Domain|
 |createCloudWatchAlarms|`boolean`|Whether to create recommended CloudWatch alarms|
-|domainEndpointEnvironmentVariableName?|`string`|Optional Name for the ElasticSearch domain endpoint environment variable set for the Lambda function.|
+|domainEndpointEnvironmentVariableName?|`string`|Optional Name for the Lambda function environment variable set to the domain endpoint. Default: DOMAIN_ENDPOINT |
 
 ## Pattern Properties
 
@@ -162,7 +162,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -208,7 +208,7 @@ class LambdaToElasticSearchAndKibana(
         :param domain_name: Cognito & ES Domain Name. Default: - None
         :param cognito_domain_name: Optional Cognito Domain Name, if provided it will be used for Cognito Domain, and domainName will be used for the Elasticsearch Domain. Default: - None
         :param create_cloud_watch_alarms: Whether to create recommended CloudWatch alarms. Default: - Alarms are created
-        :param domain_endpoint_environment_variable_name: Optional Name for the ElasticSearch domain endpoint environment variable set for the Lambda function. Default: - None
+        :param domain_endpoint_environment_variable_name: Optional Name for the Lambda function environment variable set to the domain endpoint. Default: - DOMAIN_ENDPOINT
         :param es_domain_props: Optional user provided props to override the default props for the Elasticsearch Service. Default: - Default props are used
         :param existing_lambda_obj: Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
         :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used
@@ -296,7 +296,7 @@ class LambdaToElasticSearchAndKibanaProps:
         :param domain_name: Cognito & ES Domain Name. Default: - None
         :param cognito_domain_name: Optional Cognito Domain Name, if provided it will be used for Cognito Domain, and domainName will be used for the Elasticsearch Domain. Default: - None
         :param create_cloud_watch_alarms: Whether to create recommended CloudWatch alarms. Default: - Alarms are created
-        :param domain_endpoint_environment_variable_name: Optional Name for the ElasticSearch domain endpoint environment variable set for the Lambda function. Default: - None
+        :param domain_endpoint_environment_variable_name: Optional Name for the Lambda function environment variable set to the domain endpoint. Default: - DOMAIN_ENDPOINT
         :param es_domain_props: Optional user provided props to override the default props for the Elasticsearch Service. Default: - Default props are used
         :param existing_lambda_obj: Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
         :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used
@@ -355,9 +355,9 @@ class LambdaToElasticSearchAndKibanaProps:
     def domain_endpoint_environment_variable_name(
         self,
     ) -> typing.Optional[builtins.str]:
-        '''Optional Name for the ElasticSearch domain endpoint environment variable set for the Lambda function.
+        '''Optional Name for the Lambda function environment variable set to the domain endpoint.
 
-        :default: - None
+        :default: - DOMAIN_ENDPOINT
         '''
         result = self._values.get("domain_endpoint_environment_variable_name")
         return typing.cast(typing.Optional[builtins.str], result)
